/*  gnutrition - a nutrition and diet analysis program.
 *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

void
gnutr_show_nutr_goal_dlg( void);

void
on_ok_gdlg_button_released( GtkButton *button,
		                    gpointer   user_data);

void
on_cancel_gdlg_button_released( GtkButton *button,
		                        gpointer   user_data);

void
on_save_gdlg_button_released( GtkButton *button,
		                       gpointer   user_data);


void
on_female_gdlg_radio_toggled( GtkWidget *radio,
                              gpointer data);

void
on_calculate_gdlg_button_released( GtkButton *button,
                                   gpointer user_data);
